%define debug_package %{nil}

%bcond_without python3
%bcond_with python2

Summary: Tools for building live CDs
Name: livecd-tools
Version: 31.0
Release:    1%{?dist}
License: GPLv2
URL: https://github.com/livecd-tools/livecd-tools
Source0: https://releases.pagure.org/%{name}/%{name}-%{version}.tar.gz
Patch0:  livecd-tools-31.0-py312-distutils-removal.patch

BuildRequires: make
%if %{with python2}
BuildRequires: python2-devel
%endif
%if %{with python3}
BuildRequires: python3-devel
%endif
BuildRequires: /usr/bin/pod2man

%if %{with python3}
Requires: python3-imgcreate = %{version}-%{release}
%else
Requires: python2-imgcreate = %{version}-%{release}
%endif

Conflicts: livecd-tools < 25.0

%ifarch %{ix86} x86_64
Requires: livecd-iso-to-mediums = %{version}-%{release}
%endif

%description
Tools for generating live CDs on Fedora based systems including
derived distributions such as RHEL, CentOS and others. See
http://fedoraproject.org/wiki/FedoraLiveCD for more details.

%package -n python-imgcreate-sysdeps
Summary: Common system dependencies for python-imgcreate
Requires: coreutils
Requires: xorriso >= 1.4.8
Requires: isomd5sum
Requires: parted
Requires: util-linux
Requires: dosfstools >= 2.11-8
Requires: e2fsprogs
Requires: lorax >= 18.3
Requires: rsync

%ifarch %{ix86} x86_64
Requires: syslinux-extlinux
%endif

Requires: dumpet
Requires: sssd-client
Requires: cryptsetup
Requires: squashfs-tools
Requires: policycoreutils
Requires: selinux-policy-targeted
Requires: dracut


%description -n python-imgcreate-sysdeps
This package describes the common system dependencies for
python-imgcreate.

%if %{with python2}
%package -n python2-imgcreate
Summary: Python 2 modules for building system images
%{?python_provide:%python_provide python2-imgcreate}
Requires: python-imgcreate-sysdeps = %{version}-%{release}
Requires: python2-dnf >= 1.1.0
Requires: python2-pyparted
Requires: python2-kickstart
Requires: python2-libselinux
Requires: python2-dbus
Requires: python2-urlgrabber

%description -n python2-imgcreate
Python 2 modules that can be used for building images for things
like live image or appliances.
%endif

%if %{with python3}
%package -n python3-imgcreate
Summary: Python 3 modules for building system images
%{?python_provide:%python_provide python3-imgcreate}
Requires: python-imgcreate-sysdeps = %{version}-%{release}
Requires: python3-pyparted
Requires: python3-dnf >= 1.1.0
Requires: python3-kickstart
Requires: python3-urlgrabber
Requires: libselinux-python3
Requires: python3-dbus

%description -n python3-imgcreate
Python 3 modules that can be used for building images for things
like live image or appliances.
%endif

%ifarch %{ix86} x86_64
%package -n livecd-iso-to-mediums
Summary: Tools for installing ISOs to different mediums
Requires: python-imgcreate-sysdeps = %{version}-%{release}
Conflicts: livecd-tools < 25.0

%description -n livecd-iso-to-mediums
Tools for installing Live CD ISOs to different mediums
(e.g. USB sticks, hard drives, PXE boot, etc.)
%endif

%prep
%autosetup -p1

%build

%install
%if %{with python2}
%make_install PYTHON=python2
%endif

%if %{with python3}
%make_install PYTHON=python3
%endif

rm -rf %{buildroot}%{_datadir}/doc/%{name}

%ifnarch %{ix86} x86_64
rm -rfv %{buildroot}%{_bindir}/livecd-iso-to-*
rm -rfv %{buildroot}%{_mandir}/man8/livecd-iso-to-*
%endif

%files
%license COPYING
%doc AUTHORS README HACKING
%doc config/livecd-mageia-minimal-*.ks
%{_mandir}/man*/*
%exclude %{_mandir}/man8/livecd-iso-to-disk.8*
%{_bindir}/livecd-creator
%{_bindir}/image-creator
%{_bindir}/liveimage-mount
%{_bindir}/editliveos
%{_bindir}/mkbiarch

%files -n python-imgcreate-sysdeps

%if %{with python2}
%files -n python2-imgcreate
%license COPYING
%doc API
%{python2_sitelib}/imgcreate
%endif

%if %{with python3}
%files -n python3-imgcreate
%license COPYING
%doc API
%{python3_sitelib}/imgcreate
%endif

%ifarch %{ix86} x86_64
%files -n livecd-iso-to-mediums
%license COPYING
%{_bindir}/livecd-iso-to-disk
%{_bindir}/livecd-iso-to-pxeboot
%{_mandir}/man8/livecd-iso-to-disk.8*
%endif

%changelog
* Thu Aug 22 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 31.0-1
- initial build
